abacusai.agent_conversation — AbacusAI documentation

# abacusai.agent_conversation

## Classes

`AgentConversation` | List of messages with Agent chat

## Module Contents

class abacusai.agent_conversation.AgentConversation(client, messages={})

  Bases: `abacusai.return_class.AbstractApiClass`

  List of messages with Agent chat

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - messages (AgentConversationMessage) – list of messages in the conversation with agent.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict